# Google Books Upload

Simple CLI tool and library to manage books in Google Play Books

In many ways an implementation of this: https://github.com/googleapis/googleapis.github.io/blob/bd37dbb7790827b0228d971e758fbcfc8a04b8e2/HowToRPC.md
